SolarMonth class

阳历月 @author 6tail

Constructors

SolarMonth()
SolarMonth.fromDate(DateTime date)
SolarMonth.fromYm(int year, int month)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDays() → List<Solar>
getMonth() → int
getWeeks(int start) → List<SolarWeek>
getYear() → int
next(int months) → SolarMonth
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFullString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited